@@ -43,7 +43,7 @@ def compile(model, input_shape, library, model_label, scripts, input_kwargs, asy
     else:
         verbose_print("Model not found on server.", MID_VERBOSITY)
         verbose_print("Saving model locally...", MID_VERBOSITY)
-        file_path = save_model(model, library)
+        file_path = save_model(model, library, input_shape)
         with open(file_path, "rb") as file:
             file.seek(0, os.SEEK_END)
             size = file.tell()
