@@ -4,15 +4,15 @@ import os
 import sys
 import tarfile
 from io import BytesIO
-
+from collections.abc import Iterable
 import numpy as np
 
-
 pytorch_str = "pytorch"
 mxnet_str = "mxnet"
 TF_str = "TF"
 TFLITE_str = "TFLITE"
 FILE_str = "FILE"
+onnx_str = "onnx"
 
 
 def convert_to_numpy(data):
@@ -22,7 +22,7 @@ def convert_to_numpy(data):
         return framework_to_numpy(data)
 
 
-def save_model(model, library: str):
+def save_model(model, library: str, input_shape: list):
     model_path = model
     if not isinstance(model, str):
         #     with tempfile.TemporaryDirectory() as t_dir:
@@ -69,6 +69,36 @@ def save_model(model, library: str):
                     tar.add(file, arcname=os.path.basename(file))
         elif library == "TF1":
             model_path += ".pb"
+        elif library == onnx_str:
+            model_path += ".onnx"
+            try:
+                from onnx import ModelProto, save
+                if isinstance(model, ModelProto):
+                    save(model, model_path)
+            except ModuleNotFoundError as _:
+                from ..common import npu_print
+                npu_print("To use onnx install onnx", level="ERROR")
+                sys.exit(1)
+            try:
+                from torch import nn, ones, onnx
+                if isinstance(model, nn.Module):
+                    input_name = "input"
+                    with open(model_path, "wb") as f:
+                        if len(input_shape) > 0 and isinstance(input_shape[0], Iterable):
+                            input_samples = {f"{input_name}{i}": ones(input_shape[i]) for i in range(len(input_shape))}
+                        else:
+                            input_samples = {input_name: ones(input_shape)}
+                        dynamic_axes_inputs = {name: {0: 'batch_size'} for name in input_samples}
+                        onnx.export(model, tuple(input_samples.values()), f=f,
+                                    export_params=True,
+                                    do_constant_folding=True,
+                                    input_names=list(input_samples.keys()),
+                                    output_names=['output'],
+                                    dynamic_axes={**dynamic_axes_inputs, 'output': {0: 'batch_size'}})
+            except ModuleNotFoundError as _:
+                from ..common import npu_print
+                npu_print("To use pytorch lightning with onnx backend install onnx", level="ERROR")
+                sys.exit(1)
         else:
             raise ValueError("Model type: " + str(library) + " not defined")
     return model_path
@@ -109,6 +139,8 @@ def hash_model(model, library):
                 hash.update(utf_str(param))
         except NotImplementedError:
             return ""
+    elif library == onnx_str:
+        return ""
     else:
         raise ValueError("Cannot hash... Model type: {} not defined.".format(library))
     return hash.hexdigest()
@@ -171,6 +203,12 @@ def determine_model(model):
             return mxnet_str
     except:
         pass
+    try:
+        from onnx import ModelProto
+        if isinstance(model, ModelProto):
+            return onnx_str
+    except:
+        pass
     if isinstance(model, str):
         if model.endswith(".pt"):
             return pytorch_str
